@@ -4,7 +4,7 @@ function(x,y=NULL) {
     result <- sd(x,na.rm=TRUE)/sqrt(length(na.omit(x)))
   } else {
     p <- x/y
-    result <- sqrt((p*(1-p))/(y-1))
+    result <- sqrt((p*(1-p))/y)
   }
   return(result)
 }
